@@ -1,7 +1,7 @@
 /* msgbox.c - 2000/10/13 */
 /*
  *  EasyTAG - Tag editor for MP3 and Ogg Vorbis files
- *  Copyright (C) 2000-2003  Jerome Couderc <j.couderc@ifrance.com>
+ *  Copyright (C) 2000-2003  Jerome Couderc <easytag@gmail.com>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,15 +20,16 @@
 /* Note: Some pieces of codes come from gnome-dialog.c
  */
 
+#include <config.h>
 
 #include <gtk/gtk.h>
+#include <glib/gi18n-lib.h>
 #include <stdarg.h>
 
 #include "msgbox.h"
 #include "easytag.h"
 #include "misc.h"
 #include "setting.h"
-#include "i18n.h"
 
 
 static void msg_box_class_init (MsgBoxClass *class);
@@ -38,30 +39,30 @@ static void msg_box_show (GtkWidget *widget);
 static gint msg_box_delete_event (GtkWidget *widget, GdkEventAny *event);
 static void msg_box_button_clicked (GtkButton *button, gpointer data);
 void        check_button_toggled (GtkCheckButton *checkbutton, gpointer data);
-GtkWidget  *Create_Msgbox_Pixmap (gint message_type);
 
 
 static GtkDialogClass *parent_klass = NULL;
 
 
-GtkType msg_box_get_type (void)
+GType msg_box_get_type(void)
 {
-    static guint mb_type = 0;
+    static GType mb_type = 0;
 
     if (!mb_type)
     {
-        GtkTypeInfo mb_info = 
+        GTypeInfo mb_info =
         {
-            "MsgBox",
-            sizeof(MsgBox),
             sizeof(MsgBoxClass),
-            (GtkClassInitFunc)msg_box_class_init,
-            (GtkObjectInitFunc)msg_box_init,
-            /* reserved_1 */ NULL,
-            /* reserved_2 */ NULL,
-            (GtkClassInitFunc) NULL
+            NULL,
+            NULL,
+            (GClassInitFunc) msg_box_class_init,
+            NULL,
+            NULL,
+            sizeof(MsgBox),
+            0,
+            (GInstanceInitFunc) msg_box_init
         };
-        mb_type = gtk_type_unique (gtk_dialog_get_type(), &mb_info);
+        mb_type = g_type_register_static(GTK_TYPE_DIALOG, "MsgBox", &mb_info, 0);
     }
     return mb_type;
 }
@@ -73,7 +74,7 @@ static void msg_box_button_clicked (GtkButton *button, gpointer data)
 
     g_return_if_fail( (mb = MSG_BOX(data)) );
 
-    mb->button_clicked = GPOINTER_TO_INT(gtk_object_get_data(GTK_OBJECT(button),"button_value"));
+    mb->button_clicked = GPOINTER_TO_INT(g_object_get_data(G_OBJECT(button),"button_value"));
 
     if (gtk_main_level()>1)
         gtk_main_quit();
@@ -113,7 +114,7 @@ static void msg_box_init (MsgBox *mb)
 /*
  * Create a new message box
  */
-GtkWidget *msg_box_new (gchar *title, gchar *message, gint icon, 
+GtkWidget *msg_box_new (gchar *title, gchar *message, const gchar *stock_id,
             /* Put all the buttons to display, and terminate by 0 */
             ...)
 {
@@ -129,14 +130,13 @@ GtkWidget *msg_box_new (gchar *title, gchar *message, gint icon,
 
     g_return_val_if_fail(message!=NULL, NULL);
 
-    mb = gtk_type_new(msg_box_get_type());
-    mb->icon = icon;
+    mb = MSG_BOX(g_object_new(TYPE_MSG_BOX, NULL));
+    //mb->icon = icon;
     mb->check_button = gtk_check_button_new_with_label(_("Repeat action for the rest of the files")); /* Can save or cancel all files */
 
     /* Window configuration */
     gtk_window_set_title(GTK_WINDOW(mb),title);
     gtk_window_set_transient_for(GTK_WINDOW(mb),GTK_WINDOW(MainWindow));
-    gtk_window_set_policy(GTK_WINDOW(mb),FALSE,FALSE,FALSE);
     gtk_window_set_modal(GTK_WINDOW(mb),TRUE);
 
     if (MESSAGE_BOX_POSITION_NONE)
@@ -145,24 +145,27 @@ GtkWidget *msg_box_new (gchar *title, gchar *message, gint icon,
         gtk_window_set_position(GTK_WINDOW(mb),GTK_WIN_POS_CENTER);
     else if (MESSAGE_BOX_POSITION_MOUSE)
         gtk_window_set_position(GTK_WINDOW(mb),GTK_WIN_POS_MOUSE);
+    else if (MESSAGE_BOX_POSITION_CENTER_ON_PARENT)
+        gtk_window_set_position(GTK_WINDOW(mb),GTK_WIN_POS_CENTER_ON_PARENT);
+
 
     /* Table to put: the pixmap, the message and the check button */
     Table = gtk_table_new(2,2,FALSE);
     gtk_box_pack_start(GTK_BOX(GTK_DIALOG(mb)->vbox),Table,TRUE,TRUE,0);
-    gtk_container_set_border_width(GTK_CONTAINER(Table),5);
+    gtk_container_set_border_width(GTK_CONTAINER(Table),4);
     gtk_widget_show(Table);
 
     /* The Pixmap */
-    Pixmap = Create_Msgbox_Pixmap(mb->icon);
+    Pixmap = gtk_image_new_from_stock(stock_id, GTK_ICON_SIZE_DIALOG);
     gtk_table_attach_defaults(GTK_TABLE(Table),Pixmap,0,1,0,1);
     //gtk_table_attach(GTK_TABLE(Table),Pixmap,0,1,0,1,GTK_FILL,GTK_FILL,0,0);
-    gtk_misc_set_padding(GTK_MISC(Pixmap),15,15);
+    gtk_misc_set_padding(GTK_MISC(Pixmap),6,6);
     gtk_widget_show(Pixmap);
 
     /* The Message */
     Label = gtk_label_new (message);
     gtk_table_attach_defaults(GTK_TABLE(Table),Label,1,2,0,1);
-    gtk_misc_set_padding(GTK_MISC(Label),5,10);
+    gtk_misc_set_padding(GTK_MISC(Label),6,6);
     gtk_label_set_justify(GTK_LABEL(Label),GTK_JUSTIFY_CENTER);
     //gtk_label_set_line_wrap(GTK_LABEL(Label),TRUE);
     gtk_widget_show(Label);
@@ -170,27 +173,26 @@ GtkWidget *msg_box_new (gchar *title, gchar *message, gint icon,
     /* The Check Button */
     gtk_table_attach_defaults(GTK_TABLE(Table),mb->check_button,0,2,1,2);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(mb->check_button),mb->check_button_state);
-    gtk_signal_connect (GTK_OBJECT(mb->check_button),"toggled",
-        GTK_SIGNAL_FUNC(check_button_toggled),mb);
+    g_signal_connect(G_OBJECT(mb->check_button),"toggled",G_CALLBACK(check_button_toggled),mb);
     gtk_widget_show(mb->check_button);
 
 
     /* Buttons */
     ButtonBox = gtk_hbutton_box_new();
-    gtk_button_box_set_spacing(GTK_BUTTON_BOX(ButtonBox),15);
-    gtk_button_box_set_layout(GTK_BUTTON_BOX(ButtonBox),GTK_BUTTONBOX_END);
+    gtk_box_set_spacing(GTK_BOX(ButtonBox), 15);
+    gtk_button_box_set_layout(GTK_BUTTON_BOX(ButtonBox), GTK_BUTTONBOX_END);
     gtk_container_add(GTK_CONTAINER(GTK_DIALOG(mb)->action_area),ButtonBox);
 
     /* Read buttons from variable arguments */
-    va_start (cursor,icon);
+    va_start (cursor,stock_id);
     while ( (cursor_value = va_arg(cursor,gint)) != 0 )
     {
         Button = Create_Button_With_Pixmap(cursor_value);
         gtk_container_add(GTK_CONTAINER(ButtonBox),Button);
         GTK_WIDGET_SET_FLAGS(Button,GTK_CAN_DEFAULT);
-        gtk_signal_connect(GTK_OBJECT(Button),"destroy",(GtkSignalFunc)gtk_widget_destroyed,&Button);
-        gtk_signal_connect(GTK_OBJECT(Button),"clicked",(GtkSignalFunc)msg_box_button_clicked,mb);
-        gtk_object_set_data(GTK_OBJECT(Button),"button_value",GINT_TO_POINTER(cursor_value));
+        g_signal_connect(G_OBJECT(Button),"destroy", G_CALLBACK(gtk_widget_destroyed),&Button);
+        g_signal_connect(G_OBJECT(Button),"clicked", G_CALLBACK(msg_box_button_clicked),mb);
+        g_object_set_data(G_OBJECT(Button),"button_value", GINT_TO_POINTER(cursor_value));
     }
     va_end(cursor);
     gtk_widget_grab_default(Button);
@@ -217,7 +219,7 @@ void msg_box_destroy (GtkObject *object)
 
 
 static gint msg_box_delete_event (GtkWidget *widget, GdkEventAny *event)
-{ 
+{
     MsgBox *mb;
 
     g_return_val_if_fail((mb = MSG_BOX(widget)), FALSE);
@@ -226,7 +228,7 @@ static gint msg_box_delete_event (GtkWidget *widget, GdkEventAny *event)
     mb->button_clicked = -1;
 
     if (gtk_main_level()>1)
-        gtk_main_quit(); 
+        gtk_main_quit();
 
     return TRUE;
 }
@@ -284,6 +286,19 @@ void msg_box_check_button_set_active (MsgBox *msgbox, gboolean is_active)
 }
 
 
+/*
+ * Get state of the check_button
+ */
+gboolean msg_box_check_button_get_active (MsgBox *msgbox)
+{
+    MsgBox *mb;
+
+    g_return_val_if_fail((mb = MSG_BOX(msgbox)),FALSE);
+
+    return gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(mb->check_button));
+}
+
+
 /*
  * Hide the check_button.
  */
@@ -295,51 +310,3 @@ void msg_box_hide_check_button (MsgBox *msgbox)
 
     gtk_widget_hide(mb->check_button);
 }
-
-
-
-/*
- * Create the pixmap for the message
- */
-#include "../pixmaps/msg-error.xpm"
-#include "../pixmaps/msg-info.xpm"
-#include "../pixmaps/msg-question.xpm"
-#include "../pixmaps/msg-warning.xpm"
-GtkWidget *Create_Msgbox_Pixmap (gint message_type)
-{
-    GtkWidget *PixmapIcon    = NULL;
-    GdkPixmap *pixmap    = NULL;
-    GdkBitmap *mask        = NULL;
-
-    gtk_widget_realize(MainWindow);
-    switch (message_type)
-    {
-        case MSG_INFO:
-            pixmap = gdk_pixmap_create_from_xpm_d(MainWindow->window,&mask,NULL,msg_info_xpm);
-            break;
-        case MSG_ERROR:
-            pixmap = gdk_pixmap_create_from_xpm_d(MainWindow->window,&mask,NULL,msg_error_xpm);
-            break;
-        case MSG_QUESTION:
-            pixmap = gdk_pixmap_create_from_xpm_d(MainWindow->window,&mask,NULL,msg_question_xpm);
-            break;
-        case MSG_WARNING:
-            pixmap = gdk_pixmap_create_from_xpm_d(MainWindow->window,&mask,NULL,msg_warning_xpm);
-            break;
-        default:
-            g_print(_("Warning: Unknown pixmap asked!\n"));
-            pixmap = NULL;
-            break;
-    }
-
-    /* Create Icon */
-    if (pixmap)
-    {
-        PixmapIcon = gtk_pixmap_new(pixmap,mask);
-        gdk_pixmap_unref(pixmap);
-        gdk_pixmap_unref(mask);
-        //gtk_misc_set_padding(GTK_MISC(PixmapIcon),5,10);
-    }
-
-    return PixmapIcon;
-}
