@@ -1,7 +1,7 @@
 /* prefs.h - 2000/05/06 */
 /*
  *  EasyTAG - Tag editor for MP3 and Ogg Vorbis files
- *  Copyright (C) 2000-2003  Jerome Couderc <j.couderc@ifrance.com>
+ *  Copyright (C) 2000-2003  Jerome Couderc <easytag@gmail.com>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -38,51 +38,74 @@ GtkWidget *LoadOnStartup;
 GtkWidget *DefaultPathToMp3;
 GtkWidget *BrowserLineStyleOptionMenu;
 GtkWidget *BrowserExpanderStyleOptionMenu;
-GtkWidget *WriteId3v1Tag;
-GtkWidget *WriteId3v2Tag;
-GtkWidget *StripTagWhenEmptyFields;
 GtkWidget *BrowseSubdir;
+GtkWidget *BrowseHiddendir;
 GtkWidget *OpenSelectedBrowserNode;
-GtkWidget *KeepTreeBrowserInMemory;
-GtkWidget *ConvertOldId3v2TagVersion;
-GtkWidget *SaveConfigBeforeExit;
+
+GtkListStore *DefaultPathModel;
 
 /* User interface */
-GtkWidget *SetMainWindowSize;
-GtkWidget *MainWindowHeight;
-GtkWidget *MainWindowWidth;
-GtkWidget *MainWindowButton;
-GtkWidget *SetPaneHandlePosition1;
-GtkWidget *PaneHandlePosition1;
-GtkWidget *PaneHandleButton1;
-GtkWidget *SetPaneHandlePosition2;
-GtkWidget *PaneHandlePosition2;
-GtkWidget *PaneHandleButton2;
-
 GtkWidget *ShowHeaderInfos;
-GtkWidget *UseColoredTooltips;
+GtkWidget *ChangedFilesDisplayedToRed;
+GtkWidget *ChangedFilesDisplayedToBold;
 
 /* Misc */
-GtkWidget *ReplaceIllegalCharactersInFilename;
-GtkWidget *DateAutoCompletion;
-GtkWidget *NumberTrackFormated;
-GtkWidget *NumberTrackFormatedSpinButton;
-GtkWidget *OggTagWriteXmmsComment;
-GtkWidget *SortingFileOptionMenu;
+GtkWidget *SortingFileCombo;
 GtkWidget *SortingFileCaseSensitive;
-GtkWidget *UseCharacterSetTranslation;
-GtkWidget *FileCharacterSetEntry;
-GtkWidget *UserCharacterSetEntry;
 
 GtkWidget *MessageBoxPositionNone;
 GtkWidget *MessageBoxPositionCenter;
 GtkWidget *MessageBoxPositionMouse;
+GtkWidget *MessageBoxPositionCenterOnParent;
+
+GtkWidget *FilePlayerCombo;
+GtkListStore *FilePlayerModel;
+
+/* File Settings */
+GtkWidget *ReplaceIllegalCharactersInFilename;
+GtkWidget *FilenameExtensionNoChange;
+GtkWidget *FilenameExtensionLowerCase;
+GtkWidget *FilenameExtensionUpperCase;
+GtkWidget *PreserveModificationTime;
+
+GtkWidget *FilenameCharacterSetOther;
+GtkWidget *FilenameCharacterSetApproximate;
+GtkWidget *FilenameCharacterSetDiscard;
+
+/* Tag Settings */
+GtkWidget *WriteId3v1Tag;
+GtkWidget *WriteId3v2Tag;
+GtkWidget *WriteId3TagsInFlacFiles;
+GtkWidget *UseId3v2Padding;
+GtkWidget *StripTagWhenEmptyFields;
+GtkWidget *ConvertOldId3v2TagVersion;
+
+GtkWidget *UseId3ISO88591CharacterSet;
+GtkWidget *UseId3ISO88591ThenUnicodeCharacterSet;
+GtkWidget *UseId3UnicodeCharacterSet;
+GtkWidget *UseNonStandardId3ReadingCharacterSet;
+GtkWidget *UseNonStandardId3WritingCharacterSet;
+GtkWidget *FileReadingCharacterSetCombo;
+GtkWidget *FileWritingCharacterSetCombo;
+
+GtkWidget *FileWritingCharacterSetOther;
+GtkWidget *FileWritingCharacterSetApproximate;
+GtkWidget *FileWritingCharacterSetDiscard;
+
+GtkWidget *DateAutoCompletion;
+GtkWidget *NumberTrackFormated;
+GtkWidget *NumberTrackFormatedSpinButton;
+GtkWidget *OggTagWriteXmmsComment;
+GtkWidget *SetFocusToSameTagField;
+GtkWidget *SetFocusToFirstTagField;
 
-GtkWidget *FilePlayerEntry;
 
 /* Scanner */
-GtkWidget *ConvertUnderscoreAndP20IntoSpace;
-GtkWidget *ConvertSpaceIntoUnderscore;
+GtkWidget *FTSConvertUnderscoreAndP20IntoSpace;
+GtkWidget *FTSConvertSpaceIntoUnderscore;
+GtkWidget *RFSConvertUnderscoreAndP20IntoSpace;
+GtkWidget *RFSConvertSpaceIntoUnderscore;
+GtkWidget *PFSDontUpperSomeWords;
 GtkWidget *OverwriteTagField;
 GtkWidget *OpenScannerWindowOnStartup;
 GtkWidget *ScannerWindowOnTop;
@@ -90,22 +113,27 @@ GtkWidget *ScannerWindowOnTop;
 GtkWidget *SetDefaultComment;
 GtkWidget *DefaultComment;
 GtkWidget *Crc32Comment;
-
-GtkWidget *SetScannerWindowPosition;
-GtkWidget *ScannerWindowX;
-GtkWidget *ScannerWindowY;
-GtkWidget *ScannerWindowButton;
+GtkListStore *DefaultCommentModel;
 
 /* CDDB */
-GtkWidget *CddbServerName;
-GtkWidget *CddbServerPort;
-GtkWidget *CddbServerCgiPath;
+GtkWidget *CddbServerNameAutomaticSearch;
+GtkWidget *CddbServerPortAutomaticSearch;
+GtkWidget *CddbServerCgiPathAutomaticSearch;
+GtkWidget *CddbServerNameAutomaticSearch2;
+GtkWidget *CddbServerPortAutomaticSearch2;
+GtkWidget *CddbServerCgiPathAutomaticSearch2;
+GtkWidget *CddbServerNameManualSearch;
+GtkWidget *CddbServerPortManualSearch;
+GtkWidget *CddbServerCgiPathManualSearch;
 GtkWidget *CddbUseProxy;
 GtkWidget *CddbProxyName;
 GtkWidget *CddbProxyPort;
 GtkWidget *CddbProxyUserName;
 GtkWidget *CddbProxyUserPassword;
 
+GtkWidget *CddbLocalPath;
+GtkListStore *CddbLocalPathModel;
+
 GtkWidget *SetCddbWindowSize;
 GtkWidget *CddbWindowWidth;
 GtkWidget *CddbWindowHeight;
@@ -114,6 +142,9 @@ GtkWidget *SetCddbPaneHandlePosition;
 GtkWidget *CddbPaneHandlePosition;
 GtkWidget *CddbPaneHandleButton;
 
+GtkWidget *CddbFollowFile;
+GtkWidget *CddbUseDLM;  // Also used in the cddb.c
+
 
 /* Confirmation */
 GtkWidget *ConfirmBeforeExit;
@@ -130,6 +161,7 @@ GtkWidget *ConfirmWritePlayList;
 
 void Init_OptionsWindow (void);
 void Open_OptionsWindow (void);
+void OptionsWindow_Apply_Changes (void);
 
 void File_Selection_Window_For_File      (GtkWidget *widget);
 void File_Selection_Window_For_Directory (GtkWidget *widget);
