@@ -1,7 +1,7 @@
 /* scan.h - 2000/06/16 */
 /*
  *  EasyTAG - Tag editor for MP3 and Ogg Vorbis files
- *  Copyright (C) 2000-2003  Jerome Couderc <j.couderc@ifrance.com>
+ *  Copyright (C) 2000-2003  Jerome Couderc <easytag@gmail.com>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -32,12 +32,18 @@ GtkWidget *ScannerWindow;
 GtkWidget *SWScanButton;    // To enable/disable it in easytag.c
 
 
-typedef enum
+enum
 {
     SCANNER_FILL_TAG = 0,
     SCANNER_RENAME_FILE,
     SCANNER_PROCESS_FIELDS
-} Scanner_Option_Menu_Items_Value; // Add a new item : Min and Max values used in Open_ScannerWindow
+}; // Add a new item : Min and Max values used in Open_ScannerWindow
+
+enum {
+    MASK_EDITOR_TEXT,
+    MASK_EDITOR_COUNT
+};
+
 
 
 /**************
@@ -48,10 +54,18 @@ void   Scan_Tag_With_Mask                   (ET_File *ETFile);
 void   Scan_Rename_File_With_Mask           (ET_File *ETFile);
 void   Scan_Process_Fields                  (ET_File *ETFile);
 void   Scan_Select_Mode_And_Run_Scanner     (ET_File *ETFile);
-gchar *Scan_Generate_New_Filename_From_Mask (ET_File *ETFile, gchar *mask);
-GList *Scan_Generate_New_Tag_From_Mask      (ET_File *ETFile, gchar *mask);
-void   Scan_Rename_File_Generate_Preview    (void);
-void   Scan_Fill_Tag_Generate_Preview       (void);
+gchar *Scan_Generate_New_Filename_From_Mask       (ET_File *ETFile, gchar *mask, gboolean no_dir_check_or_conversion);
+GList *Scan_Generate_New_Tag_From_Mask            (ET_File *ETFile, gchar *mask);
+gchar *Scan_Generate_New_Directory_Name_From_Mask (ET_File *ETFile, gchar *mask, gboolean no_dir_check_or_conversion);
+void   Scan_Rename_File_Generate_Preview      (void);
+void   Scan_Fill_Tag_Generate_Preview         (void);
+void   Scan_Rename_Directory_Generate_Preview (void);
+
+void   Scan_Use_Fill_Tag_Scanner            (void);
+void   Scan_Use_Rename_File_Scanner         (void);
+void   Scan_Use_Process_Fields_Scanner      (void);
+
+gboolean Scan_Check_Rename_File_Mask (GtkObject *widget_to_show_hide, GtkEntry *widget_source);
 
 void Scan_Process_Fields_All_Uppercase           (gchar *text);
 void Scan_Process_Fields_All_Downcase            (gchar *text);
@@ -64,19 +78,12 @@ void Scan_Process_Fields_Keep_One_Space          (gchar *text);
 void Scan_Convert_Underscore_Into_Space (gchar *string);
 void Scan_Convert_P20_Into_Space        (gchar *string);
 void Scan_Convert_Space_Into_Undescore  (gchar *string);
+void Scan_Convert                       (gchar *string);
 
 void Init_ScannerWindow (void);
-void Open_ScannerWindow (Scanner_Option_Menu_Items_Value scanner_type);
-gboolean Scanner_Option_Menu_Get_Active_Menu_Item (Scanner_Option_Menu_Items_Value item);
-void Scan_Apply_Changes (void);
+void Open_ScannerWindow (gint scanner_type);
+void ScannerWindow_Apply_Changes (void);
 
-void Scan_Display_Info (void);
 void Scan_Set_Scanner_Window_Init_Position (void);
 
-
-/* For debugging */
-void Scan_Display_Data_List (GList *list);
-void Scan_Display_Data_List_Masks_List (void);
-
-
 #endif /* __SCAN_H__ */
